/*
** Module   : MenuConfig.java
** Abstract : Menu widget attribute container.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 VIG 20141029          Created initial version. 
** 002 VIG 20150119          Added externalization methods implementation.
*/
package com.goldencode.p2j.ui;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

/**
 * MENU widget configuration container.
 */
public class MenuConfig
extends PaneConfig
{
   /**  
    * Progress POPUP-ONLY attribute (Graphical interfaces only). Specifies whether this 
    * menu owned by a widget (<code>true</code>) or by window (<code>false</code>).
    * Set by MENUBAR option in menu definition. 
    */
   public boolean popupOnly = true;
   
   /**
    * OWNER property: window for menubar or other widget for popup menu, 
    * or 0 if not assigned. 
    */
   public int ownerId = 0;
   
   /**
    * Default constructor (only used in deserialization).
    */
   public MenuConfig()
   {
   }

   /**
    * Create a new config and associate it with the given widget.
    * 
    * @param    id
    *           The ID of the widget to which this configuration belongs.
    */
   public MenuConfig(WidgetId id)
   {
      super(id);
   }

   /**
    * Set new values from the provided configuration instance.
    * 
    * @param    config
    *           The instance from which to take values.
    */
   @Override
   public void applyConfig(WidgetConfig config)
   {
      super.applyConfig(config);
      
      MenuConfig cfg = (MenuConfig) config;
      
      popupOnly = cfg.popupOnly;
      ownerId   = cfg.ownerId;
   }

   /**
    * Replacement for the default object reading method. The latest
    * state is read from the input source.  The parent's state is
    * read first.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If payload can't be instantiated.
    */
   @Override
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      super.readExternal(in);
      
      popupOnly = in.readBoolean();
      ownerId   = in.readInt(); 
   }

   /**
    * Replacement for the default object writing method. The latest
    * state is written to the output destination.  The parent's state is
    * written first.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   @Override
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      super.writeExternal(out);
      
      out.writeBoolean(popupOnly);
      out.writeInt(ownerId);
   }
}
