/*
** Module   : Menu.java
** Abstract : Menu abstract client implementation
**
** Copyright (c) 2005-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- -----------------------------Description-----------------------------
** 001 VIG 20150116          Created initial version.
*/
package com.goldencode.p2j.ui.client;

import com.goldencode.p2j.ui.ConfigManager;
import com.goldencode.p2j.ui.MenuConfig;
import com.goldencode.p2j.ui.WidgetConfig;
import com.goldencode.p2j.ui.WidgetId;
import com.goldencode.p2j.ui.client.widget.AbstractContainer;

/**
 * <code>Menu</code> client abstract implementation class. 
 */
public abstract class Menu<O extends OutputManager<?>>
extends AbstractContainer<O>
{
   /** Frame attribute container. */
   private MenuConfig config = null; 

   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   id
    *          The widget's ID.
    * @param   cfg
    *          Configuration data.
    */
   public Menu(WidgetId id, MenuConfig cfg)
   {
   }
   
   /**
    * Replacement API for the logic which should exist in the widget's c'tor, but the logic 
    * can't be executed as it depends on the widget being registered into the official registry.
    * <p>
    * This API is called after the widget is created and added to the registry.
    * 
    * @param    id
    *           The widget's ID.
    * @param    cfg
    *           The config used to initialize this widget.
    */
   @Override
   public void initialize(WidgetId id, WidgetConfig cfg)
   {
      config = ConfigManager.getInstance().getActiveConfig(id);
      if (config == null)
      {
         config = new MenuConfig(id);
      }
      ConfigManager.getInstance().replaceConfig(config, cfg);
   }   

   /**
    * Provide access to the attributes stored in the widget.
    * 
    * @return  Reference to attribute container.
    */
   @SuppressWarnings("unchecked")
   @Override
   public MenuConfig config()
   {
      return config;
   }
   
}
